<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr">
<context>
    <name>CompletingEdit</name>
    <message>
        <source>Jump to PDF</source>
        <translation>PDF&apos;e Atla</translation>
    </message>
    <message>
        <source>No suggestions</source>
        <translation>Öneri yok</translation>
    </message>
    <message>
        <source>Ignore word</source>
        <translation>Kelimeyi yoksay</translation>
    </message>
</context>
<context>
    <name>ConfirmDelete</name>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Unable to delete</source>
        <translation>Silinemiyor</translation>
    </message>
    <message>
        <source>Some of the auxiliary files could not be removed. Perhaps you don&apos;t have permission to delete them.</source>
        <translation>Yardımcı dosyaların bir kısmı kaldırılamadı. Belki onları silmek için yetkiniz yoktur.</translation>
    </message>
    <message>
        <source>Confirm file deletion</source>
        <translation>Dosyanın silinmesini onaylayın</translation>
    </message>
    <message>
        <source>Auxiliary files to be deleted:</source>
        <translation>Silinecek yardımcı dosyalar:</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Tümünü Seç</translation>
    </message>
    <message>
        <source>Select None</source>
        <translation>Hiçbirini Seçme</translation>
    </message>
    <message>
        <source>Toggle</source>
        <translation>Seçimi ters çevir</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Find</source>
        <translation>Bul</translation>
    </message>
    <message>
        <source>Find:</source>
        <translation>Bul:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>&amp;Başa sarmala</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>&amp;Geriye doğru bul</translation>
    </message>
    <message>
        <source>Search within &amp;selection</source>
        <translation>&amp;Seçim içinde ara</translation>
    </message>
    <message>
        <source>Find &amp;all occurrences</source>
        <translation>Geçen &amp;tüm yerlerde bul</translation>
    </message>
    <message>
        <source>Search all &amp;open files</source>
        <translation>Tüm açık d&amp;osyalarda ara</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>&amp;Büyük küçük harfe duyarlı</translation>
    </message>
    <message>
        <source>W&amp;hole words</source>
        <translation>&amp;Tam kelimeler</translation>
    </message>
    <message>
        <source>&amp;Regular expression</source>
        <translation>&amp;Düzenli ifade</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>Son arama yok</translation>
    </message>
    <message>
        <source>(invalid)</source>
        <translation>(geçersiz)</translation>
    </message>
</context>
<context>
    <name>HardWrapDialog</name>
    <message>
        <source>Hard Wrap</source>
        <translation>Sabit Sözcük Kaydırma</translation>
    </message>
    <message>
        <source>Wrap lines to:</source>
        <translation>Satır kaydırma uzunluğu:</translation>
    </message>
    <message>
        <source>Current window size</source>
        <translation>Mevcut pencere boyutu</translation>
    </message>
    <message>
        <source>Line length:</source>
        <translation>Satır uzunluğu:</translation>
    </message>
    <message>
        <source>Re-wrap paragraphs</source>
        <translation>Paragrafları tekrar sarmala</translation>
    </message>
    <message>
        <source>Unwrap</source>
        <translation>Sarmalama</translation>
    </message>
</context>
<context>
    <name>PDFDocument</name>
    <message>
        <source>Open Recent</source>
        <translation>Son Açılanı Aç</translation>
    </message>
    <message>
        <source>Failed to load file &quot;%1&quot;; perhaps it is not a valid PDF document.</source>
        <translation>&quot;%1&quot; dosyası açılamadı; belki geçerli bir PDF belgesi değildir.</translation>
    </message>
    <message>
        <source>No SyncTeX data available</source>
        <translation>Kullanılabilir SyncTeX verisi yok</translation>
    </message>
    <message>
        <source>SyncTeX: &quot;%1&quot;</source>
        <translation>SyncTeX: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>%1[*] - %2</source>
        <translation>%1[*] - %2</translation>
    </message>
    <message>
        <source>page %1 of %2</source>
        <translation>sayfa %1/%2</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
    <message>
        <source>untitled.pdf[*]</source>
        <translation>isimsiz.pdf[*]</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Dosya</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Görüntüle</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Pencere</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Göster</translation>
    </message>
    <message>
        <source>Typeset</source>
        <translation>Diz</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Araç çubuğu</translation>
    </message>
    <message>
        <source>About TeXworks...</source>
        <translation>TeXworks Hakkında...</translation>
    </message>
    <message>
        <source>First Page</source>
        <translation>İlk Sayfa</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Önceki Sayfa</translation>
    </message>
    <message>
        <source>Ctrl+PgUp</source>
        <comment>shortcut key name, do not translate</comment>
        <translation>Ctrl+PgUp</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Sonraki Sayfa</translation>
    </message>
    <message>
        <source>Ctrl+PgDown</source>
        <comment>shortcut key name, do not translate</comment>
        <translation>Ctrl+PgDown</translation>
    </message>
    <message>
        <source>Last Page</source>
        <translation>Son Sayfa</translation>
    </message>
    <message>
        <source>Go to Page...</source>
        <translation>Sayfaya Git...</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Yakınlaştır</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Uzaklaştır</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Fit to Window</source>
        <translation>Pencereye Sığdır</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <source>Actual Size</source>
        <translation>Gerçek Boyut</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <source>Fit to Width</source>
        <translation>Genişliğe Sığdır</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Yeni</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Aç...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Geri Al</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Tekrar yap</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Z</source>
        <translation>Ctrl+Shift+Z</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Kes</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Yapıştır</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Temizle</translation>
    </message>
    <message>
        <source>Ctrl+Backspace</source>
        <translation>Ctrl+Backspace</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>Tercihler...</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Üst üste</translation>
    </message>
    <message>
        <source>Tile</source>
        <translation>Döşe</translation>
    </message>
    <message>
        <source>Go to Source</source>
        <translation>Kaynağa Git</translation>
    </message>
    <message>
        <source>Ctrl+&apos;</source>
        <translation>Ctrl+&apos;</translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>Şablondan Yeni...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>Full Screen</source>
        <translation>Tam Ekran</translation>
    </message>
    <message>
        <source>Ctrl+Shift+F</source>
        <translation>Ctrl+Shift+F</translation>
    </message>
    <message>
        <source>Magnify</source>
        <translation>Büyüt</translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation>Kaydır</translation>
    </message>
    <message>
        <source>Select Text</source>
        <translation>Metni Seç</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>İmgeyi Seç</translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>TeXworks ana sayfasına git</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>Posta listesine e-posta gönder</translation>
    </message>
    <message>
        <source>Side by Side</source>
        <translation>Yan yana</translation>
    </message>
    <message>
        <source>Place on Left</source>
        <translation>Sola yerleştir</translation>
    </message>
    <message>
        <source>Place on Right</source>
        <translation>Sağa Yerleştir</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>TeXworks&apos;den çık</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Find Again</source>
        <translation>Tekrar Bul</translation>
    </message>
    <message>
        <source>Find...</source>
        <translation>Bul...</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Typeset</source>
        <comment>menu title</comment>
        <translation>Diz</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <comment>action</comment>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Eklentiler</translation>
    </message>
    <message>
        <source>Scripting TeXworks</source>
        <translation>TeXworks Eklentileri</translation>
    </message>
    <message>
        <source>Reload Script List</source>
        <translation>Eklenti Listesini Yenile</translation>
    </message>
    <message>
        <source>Manage Scripts</source>
        <translation>Eklentileri Yönet</translation>
    </message>
    <message>
        <source>Show Scripts Folder</source>
        <translation>Eklenti Klasörünü Göster</translation>
    </message>
    <message>
        <source>About Scripts...</source>
        <translation>Eklentiler Hakkında...</translation>
    </message>
    <message>
        <source>Print Pdf...</source>
        <translation>Pdf Yazdır...</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>Abort typesetting</source>
        <translation>Dizgiyi durdur</translation>
    </message>
    <message>
        <source>Unfortunately, this version of %1 is unable to print Pdf documents due to various technical reasons.
</source>
        <translation>Ne yazık ki bu %1 versiyonu Pdf dokümanlarını çeşitle teknik sebepler nedeniyle yazdıramıyor.
</translation>
    </message>
    <message>
        <source>Do you want to open the file in the default viewer for printing instead?</source>
        <translation>Öntanımlı programla açarak oradan yazdırmak ister misiniz?</translation>
    </message>
    <message>
        <source> (remember to close it again to avoid access problems)</source>
        <translation> (erişim sorunlarını önlemek için tekrar kapatmayı unutmayın)</translation>
    </message>
    <message>
        <source>Settings and Resources...</source>
        <translation>Ayarlar ve Kaynaklar...</translation>
    </message>
    <message>
        <source>Clear Recent Files</source>
        <translation>Son kullanılanları temizle</translation>
    </message>
    <message>
        <source>Error initializing SyncTeX</source>
        <translation>SyncTeX başlatılırken hata</translation>
    </message>
    <message>
        <source>Go to previous view</source>
        <translation>Önceki görünüme git</translation>
    </message>
    <message>
        <source>Alt+Left</source>
        <translation>Alt+Sol</translation>
    </message>
    <message>
        <source>Single Page</source>
        <translation>Tek Sayfa</translation>
    </message>
    <message>
        <source>Single Page Continuous</source>
        <translation>Kesintisiz Tek Sayfa</translation>
    </message>
    <message>
        <source>Two Pages Continuous</source>
        <translation>Kesintisiz İkişer Sayfa</translation>
    </message>
    <message>
        <source>Jump to Source</source>
        <translation>Kaynağa Atla</translation>
    </message>
    <message>
        <source>Go to Page</source>
        <translation>Sayfaya Git</translation>
    </message>
    <message>
        <source>Page number:</source>
        <translation>Sayfa no:</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation>URL aç</translation>
    </message>
    <message>
        <source>You are in the process of opening the URL %1. Opening unknown or untrusted web adresses can be a security risk.
Do you want to continue?</source>
        <translation>%1 URL&apos;ini açmak üzeresiniz. Bilinmeyen veya güvenilmeyen web adreslerini açmak güvenlik riski oluşturabilir. Devam etmek istiyor musunuz?</translation>
    </message>
    <message>
        <source>Custom...</source>
        <translation>Özel...</translation>
    </message>
    <message>
        <source>Set Zoom</source>
        <translation>Yakınlaştırmayı ayarla</translation>
    </message>
    <message>
        <source>Zoom level:</source>
        <translation>Yakınlaştırma seviyesi:</translation>
    </message>
</context>
<context>
    <name>PDFFindDialog</name>
    <message>
        <source>Find</source>
        <translation>Bul</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>Son arama yok</translation>
    </message>
    <message>
        <source>Find in PDF</source>
        <translation>PDF içinde bul</translation>
    </message>
    <message>
        <source>Find:</source>
        <translation>Bul:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>&amp;Başa sarmala</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>&amp;Geriye doğru bul</translation>
    </message>
    <message>
        <source>Find &amp;all occurrences</source>
        <translation>Geçen &amp;tüm yerlerde bul</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>&amp;Büyük küçük harfe duyarlı</translation>
    </message>
    <message>
        <source>&amp;Sync to source</source>
        <translation>&amp;Kaynağa Eşle</translation>
    </message>
</context>
<context>
    <name>PrefsDialog</name>
    <message>
        <source>Choose Directory</source>
        <translation>Dizin Seç</translation>
    </message>
    <message>
        <source>New Tool</source>
        <translation>Yeni Araç</translation>
    </message>
    <message>
        <source>System default [%1]</source>
        <translation>Sistemde öntanımlı [%1]</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Yok</translation>
    </message>
    <message>
        <source>TeXworks Preferences</source>
        <translation>TeXworks Tercihleri</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Genel</translation>
    </message>
    <message>
        <source>Small icons</source>
        <translation>Küçük simgeler</translation>
    </message>
    <message>
        <source>Medium icons</source>
        <translation>Orta boy simgeler</translation>
    </message>
    <message>
        <source>Large icons</source>
        <translation>Büyük simgeler</translation>
    </message>
    <message>
        <source>Show text as well as icons</source>
        <translation>Simgelerle birlikte metin de göster</translation>
    </message>
    <message>
        <source>When launched, show</source>
        <translation>Başlangıçta</translation>
    </message>
    <message>
        <source>New blank document</source>
        <translation>Yeni boş belge göster</translation>
    </message>
    <message>
        <source>Template selection dialog</source>
        <translation>Şablon seçim penceresini göster</translation>
    </message>
    <message>
        <source>File Open dialog</source>
        <translation>Dosya Aç penceresini göster</translation>
    </message>
    <message>
        <source>Editor</source>
        <translation>Düzenleyici</translation>
    </message>
    <message>
        <source>Editor defaults</source>
        <translation>Düzenleyici varsayılanları</translation>
    </message>
    <message>
        <source> pt</source>
        <translation>pt</translation>
    </message>
    <message>
        <source>Tab width:</source>
        <translation>Sekme genişliği:</translation>
    </message>
    <message>
        <source>Wrap lines</source>
        <translation>Sözcük kaydır</translation>
    </message>
    <message>
        <source>Syntax coloring:</source>
        <translation>Sentaks renklendirme:</translation>
    </message>
    <message>
        <source>Auto-Indent mode:</source>
        <translation>Otomatik girintileme kipi:</translation>
    </message>
    <message>
        <source>Spell-check language:</source>
        <translation>Yazım denetimi dili:</translation>
    </message>
    <message>
        <source>Encoding:</source>
        <translation>Kodlama:</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Önizleme</translation>
    </message>
    <message>
        <source>Default scaling</source>
        <translation>Öntanımlı ölçekleme</translation>
    </message>
    <message>
        <source>Actual size</source>
        <translation>Gerçek Boyut</translation>
    </message>
    <message>
        <source>Fit to Width</source>
        <translation>Genişliğe Sığdır</translation>
    </message>
    <message>
        <source>Fit to Window</source>
        <translation>Pencereye Sığdır</translation>
    </message>
    <message>
        <source>Fixed scale:</source>
        <translation>Sabit ölçek:</translation>
    </message>
    <message>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <source>Magnifying glass</source>
        <translation>Büyüteç</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Küçük</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Orta boy</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Büyük</translation>
    </message>
    <message>
        <source>Circular magnifier</source>
        <translation>Yuvarlak büyüteç</translation>
    </message>
    <message>
        <source>Screen resolution:</source>
        <translation>Ekran çözünürlüğü:</translation>
    </message>
    <message>
        <source> dpi</source>
        <translation type="obsolete">dpi</translation>
    </message>
    <message>
        <source>Typesetting</source>
        <translation>Dizgi</translation>
    </message>
    <message>
        <source>Paths for TeX and related programs</source>
        <translation>TeX ve ilgili programlar için aranacak yollar</translation>
    </message>
    <message>
        <source>Processing tools</source>
        <translation>İşleme araçları</translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation>Düzenle...</translation>
    </message>
    <message>
        <source>Default:</source>
        <translation>Öntanımlı:</translation>
    </message>
    <message>
        <source>Line numbers</source>
        <translation>Satır numaraları</translation>
    </message>
    <message>
        <source>Global editor options</source>
        <translation>Genel editör seçenekleri</translation>
    </message>
    <message>
        <source>Highlight current line</source>
        <translation>Bulunulan satırı vurgula</translation>
    </message>
    <message>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <source>Smart Quotes mode:</source>
        <translation>Akıllı Tırnak işaretleri kipi:</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Eklentiler</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Güvenlik</translation>
    </message>
    <message>
        <source>Allow scripts to read all files (script and document files are always readable)</source>
        <translation>Eklentilerin tüm dosyaları okumasına izin ver (eklenti ve belge dosyaları her zaman okunabilir)</translation>
    </message>
    <message>
        <source>Allow scripts to write files</source>
        <translation>Eklentilerin dosya yazmasına izin ver</translation>
    </message>
    <message>
        <source>Allow scripts to run system commands</source>
        <translation>Eklentilerin sistem komutu çalıştırmasına izin ver</translation>
    </message>
    <message>
        <source>Enable plug-in scripting languages (may circumvent other restrictions on script behavior)</source>
        <translation>Eklenti dillerini etkinleştir (eklenti davranışındaki diğer kısıtlamaları kaldırabilir)</translation>
    </message>
    <message>
        <source>Debugging</source>
        <translation>Hata ayıklama</translation>
    </message>
    <message>
        <source>Enable QtScript debugger</source>
        <translation>QtScript hata ayıklayıcısını etkinleştir</translation>
    </message>
    <message>
        <source>Never</source>
        <extracomment>&quot;Hide console output&quot; mode</extracomment>
        <translation>Hiçbir zaman</translation>
    </message>
    <message>
        <source>Automatically</source>
        <extracomment>&quot;Hide console output&quot; mode</extracomment>
        <translation>Otomatik olarak</translation>
    </message>
    <message>
        <source>On success</source>
        <extracomment>&quot;Hide console output&quot; mode</extracomment>
        <translation>Hata yoksa</translation>
    </message>
    <message>
        <source>&lt;em&gt;Note:&lt;/em&gt; These are default settings. Changes to them will not affect windows that are already open. Use the respective items in the &amp;quot;Format&amp;quot; menu to achieve that.</source>
        <translation>&lt;em&gt;Not:&lt;/em&gt; Bunlar öntanımlı ayarlardır. Yapılacak değişiklikler halen açık olan pencereleri etkilemez. O amaçla &amp;quot;Biçim&amp;quot; menüsündeki ilgili seçenekleri kullanın.</translation>
    </message>
    <message>
        <source>Enable autocompletion</source>
        <translation>Kelime tamamlamayı etkinleştir</translation>
    </message>
    <message>
        <source>Hide console output:</source>
        <translation>Konsol çıktısını gizle:</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;strong&gt;Never:&lt;/strong&gt; Never hide the console output panel after typesetting.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;Automatically:&lt;/strong&gt; Hide the console output panel after successful typesetting, but only if it was hidden before.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;On Success:&lt;/strong&gt; Hide the console output panel after successful typesetting, regardless of its previous state.&lt;/p&gt;
</source>
        <translation>&lt;p&gt;&lt;strong&gt;Asla:&lt;/strong&gt; Dizgi sonrası konsol çıktısını asla gizleme.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;Otomatik:&lt;/strong&gt; Hatasız dizgi sonrası konsol çıktısını şayet önceden de gizli ise gizle.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;Hata yoksa:&lt;/strong&gt; Hatasız dizgi sonrası konsol çıktısını önceki durumunu dikkate almadan gizle.&lt;/p&gt;
</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Arayüz</translation>
    </message>
    <message>
        <source>Locale:</source>
        <translation>Yerellik:</translation>
    </message>
    <message>
        <source>Toolbar buttons:</source>
        <translation>Araç çubuğu düğmeleri</translation>
    </message>
    <message>
        <source>Open corresponding PDF preview with TeX files</source>
        <translation>TeX dosyaları ile ilgili PDF önizlemesini aç</translation>
    </message>
    <message>
        <source>Page mode:</source>
        <translation>Sayfa modu:</translation>
    </message>
    <message>
        <source>Single Page</source>
        <translation>Tek Sayfa</translation>
    </message>
    <message>
        <source>Single Page Continuous</source>
        <translation>Kesintisiz Tek Sayfa</translation>
    </message>
    <message>
        <source>Two Page Continuous</source>
        <translation>Kesintisiz İkişer Sayfa</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>TeX documents (*.tex)</source>
        <translation>TeX belgeleri (*.tex)</translation>
    </message>
    <message>
        <source>LaTeX documents (*.ltx)</source>
        <translation>LaTeX belgeleri (*.tex)</translation>
    </message>
    <message>
        <source>BibTeX databases (*.bib)</source>
        <translation>BibTeX veritabanları (*.bib)</translation>
    </message>
    <message>
        <source>Style files (*.sty)</source>
        <translation>Stil dosyaları (*.sty)</translation>
    </message>
    <message>
        <source>Class files (*.cls)</source>
        <translation>Sınıf dosyaları (*.cls)</translation>
    </message>
    <message>
        <source>Documented macros (*.dtx)</source>
        <translation>Belgelenmiş makrolar (*.dtx)</translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation>Metin dosyaları (*.txt)</translation>
    </message>
    <message>
        <source>PDF documents (*.pdf)</source>
        <translation>PDF belgeleri (*.pdf)</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Tüm dosyalar</translation>
    </message>
    <message>
        <source>Log files (*.log *.blg)</source>
        <translation>Kayıt dosyaları (*.log *.blg)</translation>
    </message>
    <message>
        <source>Auxiliary files (*.aux *.toc *.lot *.lof *.nav *.out *.snm *.ind *.idx *.bbl *.brf)</source>
        <translation>Yardımcı dosyalar (*.aux *.toc *.lot *.lof *.nav *.out *.snm *.ind *.idx *.bbl *.brf)</translation>
    </message>
</context>
<context>
    <name>ReplaceDialog</name>
    <message>
        <source>Replace</source>
        <translation>Yer Değiştir</translation>
    </message>
    <message>
        <source>Replace All</source>
        <translation>Tümünü yer değiştir</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Vazgeç</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>Son arama yok</translation>
    </message>
    <message>
        <source>No recent replacement strings</source>
        <translation>Son yer değiştirme yok</translation>
    </message>
    <message>
        <source>(invalid)</source>
        <translation>(geçersiz)</translation>
    </message>
    <message>
        <source>Replace:</source>
        <translation>Yer değiştir:</translation>
    </message>
    <message>
        <source>With:</source>
        <translation>Bununla:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>&amp;Başa sarmala</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>Geriye doğru &amp;bul</translation>
    </message>
    <message>
        <source>Replace within &amp;selection</source>
        <translation>&amp;Seçim içinde yer değiştir</translation>
    </message>
    <message>
        <source>Replace in all &amp;open files</source>
        <translation>Tüm açık d&amp;osyalarda yer değiştir</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>&amp;Büyük küçük harfe duyarlı</translation>
    </message>
    <message>
        <source>W&amp;hole words</source>
        <translation>&amp;Tam kelimeler</translation>
    </message>
    <message>
        <source>&amp;Regular expression</source>
        <translation>&amp;Düzenli ifade</translation>
    </message>
</context>
<context>
    <name>ResourcesDialog</name>
    <message>
        <source>TeXworks Settings and Resources</source>
        <translation>TeXworks Ayarları ve Kaynaklar</translation>
    </message>
    <message>
        <source>Storage Locations</source>
        <translation>Depolama Yerleri</translation>
    </message>
    <message>
        <source>Settings:</source>
        <translation>Ayarlar:</translation>
    </message>
    <message>
        <source>Resources:</source>
        <translation>Kaynaklar:</translation>
    </message>
    <message>
        <source>Registry (%1)</source>
        <translation>Kütük (%1)</translation>
    </message>
</context>
<context>
    <name>ScreenCalibrationWidget</name>
    <message>
        <source>Drag the ruler or change the value to match real world lengths.
Common paper sizes are marked as well (you may need to resize the dialog window to see them).
Use the context menu to change the units.</source>
        <translation>Cetveli sürükleyin veya değeri gerçek uzunluklara göre ayarlayın.
Yaygın kağıt boyutları işaretlidir (Bunları görmek için pencerenin boyutlarını değiştirmeniz gerekebilir).
Birimleri değiştirmek için menüyü kullanın.</translation>
    </message>
    <message>
        <source> dpi</source>
        <extracomment>dots per inch</extracomment>
        <translation> dpi</translation>
    </message>
    <message>
        <source>DIN A4</source>
        <translation>DIN A4</translation>
    </message>
    <message>
        <source>Letter</source>
        <translation>Letter</translation>
    </message>
    <message>
        <source>cm</source>
        <extracomment>this refers to the length unit of centimeters</extracomment>
        <translation>cm</translation>
    </message>
    <message>
        <source>in</source>
        <extracomment>this refers to the length unit of inches</extracomment>
        <translation>in</translation>
    </message>
</context>
<context>
    <name>ScriptManager</name>
    <message>
        <source>Manage Scripts</source>
        <translation>Eklentileri Yönet</translation>
    </message>
    <message>
        <source>Standalone Scripts</source>
        <translation>Bağımsız Eklentiler</translation>
    </message>
    <message>
        <source>Hook Scripts</source>
        <translation>Kanca Eklentiler</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>İsim: </translation>
    </message>
    <message>
        <source>Context: </source>
        <translation>Bağlam: </translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Açıklama: </translation>
    </message>
    <message>
        <source>Author: </source>
        <translation>Yazar: </translation>
    </message>
    <message>
        <source>Version: </source>
        <translation>Versiyon: </translation>
    </message>
    <message>
        <source>Shortcut: </source>
        <translation>Kısayol: </translation>
    </message>
    <message>
        <source>File: </source>
        <translation>Dosya: </translation>
    </message>
    <message>
        <source>Language: </source>
        <translation>Dil: </translation>
    </message>
    <message>
        <source>Hook: </source>
        <translation>Kanca: </translation>
    </message>
</context>
<context>
    <name>SearchResults</name>
    <message>
        <source>File</source>
        <translation>Dosya</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Satır</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Başlangıç</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Son</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Metin</translation>
    </message>
    <message>
        <source>Search Results</source>
        <translation>Arama Sonuçları</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Search Results - %1 (%2 found)</source>
        <translation>Arama Sonuçları - %1 (%2 adet bulundu)</translation>
    </message>
</context>
<context>
    <name>TWApp</name>
    <message>
        <source>File</source>
        <translation>Dosya</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Yeni</translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>Şablondan Yeni...</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>Tercihler...</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Aç...</translation>
    </message>
    <message>
        <source>Open Recent</source>
        <translation>Son Açılanı Aç</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <source>About </source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>TeXworks ana sayfasına git</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>Posta listesine e-posta gönder</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>&lt;p&gt;%1 is a simple environment for editing, typesetting, and previewing TeX documents.&lt;/p&gt;</source>
        <translation>&lt;p&gt;%1, TeX belgelerini düzenleme, dizme ve önizleme için basit bir ortamdır.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://poppler.freedesktop.org/&quot;&gt;Poppler&lt;/a&gt; PDF rendering library by Kristian H&amp;#xF8;gsberg, Albert Astals Cid and others.</source>
        <translation>&lt;br&gt;&lt;a href=&quot;http://poppler.freedesktop.org/&quot;&gt;Poppler&lt;/a&gt; PDF bezeme kitaplığı Kristian H&amp;#xF8;gsberg, Albert Astals Cid ve diğerleri tarafından.</translation>
    </message>
    <message>
        <source>&lt;br&gt;Concept and resources from &lt;a href=&quot;http://www.uoregon.edu/~koch/texshop/&quot;&gt;TeXShop&lt;/a&gt; by Richard Koch.</source>
        <translation>&lt;br&gt;Kavram ve kaynaklar Richard Koch tarafından &lt;a href=&quot;http://www.uoregon.edu/~koch/texshop/&quot;&gt;TeXShop&lt;/a&gt;&apos;dan.</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://itexmac.sourceforge.net/SyncTeX.html&quot;&gt;SyncTeX&lt;/a&gt; technology by J&amp;#xE9;r&amp;#xF4;me Laurens.</source>
        <translation>&lt;br&gt;&lt;a href=&quot;http://itexmac.sourceforge.net/SyncTeX.html&quot;&gt;SyncTeX&lt;/a&gt; teknolojisi J&amp;#xE9;r&amp;#xF4;me Laurens tarafından.</translation>
    </message>
    <message>
        <source>&lt;br&gt;Some icons used are from the &lt;a href=&quot;http://tango.freedesktop.org/&quot;&gt;Tango Desktop Project&lt;/a&gt;.</source>
        <translation>&lt;br&gt;Kullanılan bazı simgeler &lt;a href=&quot;http://tango.freedesktop.org/&quot;&gt;Tango Masaüstü Projesi&lt;/a&gt;&apos;nden.</translation>
    </message>
    <message>
        <source>&lt;p&gt;%1 translation kindly contributed by %2.</source>
        <translation>&lt;p&gt;%1 tercümesi %2 tarafından eklendi.</translation>
    </message>
    <message>
        <source>[language name]</source>
        <translation>Türkçe</translation>
    </message>
    <message>
        <source>[translator&apos;s name/email]</source>
        <translation>Sertaç Ö. Yıldız &lt;sertacyildiz＠gmail.com&gt;</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>%1 hakkında</translation>
    </message>
    <message>
        <source>Unable to access &quot;%1&quot;; perhaps your browser or mail application is not properly configured?</source>
        <translation>&quot;%1&quot; erişilemiyor; belki web tarayıcınız veya e-posta uygulamanız uygun şekilde ayarlanmamıştır?</translation>
    </message>
    <message>
        <source>Unable to create window</source>
        <translation>Pencere oluşturulamıyor</translation>
    </message>
    <message>
        <source>Something is badly wrong; %1 was unable to create a document window. The application will now quit.</source>
        <translation>Bir şeyler fena halde yanlış; %1 bir belge penceresi oluşturamadı. Uygulama şimdi sonlandırılacak.</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Dosya Aç</translation>
    </message>
    <message>
        <source>No default binary directory found</source>
        <translation>Hiçbir öntanımlı ikili dizini bulunamadı</translation>
    </message>
    <message>
        <source>None of the predefined directories for TeX-related programs could be found.&lt;p&gt;&lt;small&gt;To run any processes, you will need to set the binaries directory (or directories) for your TeX distribution using the Typesetting tab of the Preferences dialog.&lt;/small&gt;</source>
        <translation>TeX ile ilgili programlar için önceden tanımlanmış dizinlerin hiçbiri bulunamadı.&lt;p&gt;&lt;small&gt;Bir işlem çalıştırmak için Tercihler penceresindeki Dizgi sekmesinde TeX dağıtımınız için ikililer dizini (veya dizinleri) ayarlamanız gerekecek.&lt;/small&gt;</translation>
    </message>
    <message>
        <source>Unable to find help file.</source>
        <translation>Yardım dosyası bulunamıyor.</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Dosyayı Kaydet</translation>
    </message>
    <message>
        <source>Permission request</source>
        <translation>İzin isteği</translation>
    </message>
    <message>
        <source>The script &quot;%1&quot; is trying to open the file &quot;%2&quot; without sufficient permissions. Do you want to open the file?</source>
        <translation>&quot;%1&quot; eklentisi &quot;%2&quot; dosyasını yeterli izin olmadan açmaya çalışıyor. Dosyayı açmak istiyor musunuz?</translation>
    </message>
    <message>
        <source>&lt;p&gt;Distributed under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl-2.0.html&quot;&gt;GNU General Public License&lt;/a&gt;, version 2 or (at your option) any later version.</source>
        <translation>&lt;p&gt;&lt;a href=&quot;http://www.gnu.org/licenses/gpl-2.0.html&quot;&gt;GNU Genel Kamu Lisansı&lt;/a&gt;&apos;nın 2. sürümü veya (isteğinize göre) daha sonraki bir sürümü altında dağıtılır.</translation>
    </message>
    <message>
        <source>Clear Recent Files</source>
        <translation>Son kullanılanları temizle</translation>
    </message>
    <message>
        <source>&lt;br&gt;Version %1 (%2) [r.%3, %4]</source>
        <translation>&lt;br&gt;Versiyon %1 (%2) [r.%3, %4]</translation>
    </message>
    <message>
        <source>&lt;br&gt;Version %1 (%2)</source>
        <translation>&lt;br&gt;Versiyon %1 (%2)</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>TeXworks&apos;den çık</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;a href=&quot;http://www.qt.io/&quot;&gt;Qt application framework&lt;/a&gt; v%1 by The Qt Company.</source>
        <translation>&lt;p&gt;The Qt Company tarafından &lt;a href=&quot;http://www.qt.io/&quot;&gt;Qt uygulama çatısı&lt;/a&gt; v%1.</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://hunspell.github.io/&quot;&gt;Hunspell&lt;/a&gt; spell checker by L&amp;#xE1;szl&amp;#xF3; N&amp;#xE9;meth.</source>
        <translation>&lt;br&gt;L&amp;#xE1;szl&amp;#xF3; N&amp;#xE9;meth tarafından &lt;a href=&quot;http://hunspell.github.io/&quot;&gt;Hunspell&lt;/a&gt; yazım denetçisi.</translation>
    </message>
</context>
<context>
    <name>TWScriptAPI</name>
    <message>
        <source>Internal error</source>
        <translation>İç hata</translation>
    </message>
    <message>
        <source>Failed to execute system command: %1</source>
        <translation>Sistem komutu çalıştırılamadı: %1</translation>
    </message>
    <message>
        <source>Error executing system command: %1</source>
        <translation>Sistem komutu çalıştırılırken hata: %1</translation>
    </message>
    <message>
        <source>System command execution is disabled (see Preferences)</source>
        <translation>Sistem komutu çalıştırma etkin değil (bkz. Tercihler)</translation>
    </message>
    <message>
        <source>&quot;%1&quot; could not be opened.</source>
        <translation>&quot;%1&quot; açılamadı.</translation>
    </message>
    <message>
        <source>Reading all files is disabled (see Preferences)</source>
        <translation>Tüm dosyaları okuma etkin değil (bkz. Tercihler)</translation>
    </message>
    <message>
        <source>The file &quot;%1&quot; could not be opened for reading</source>
        <translation>&quot;%1&quot; dosyası okuma için açılamadı</translation>
    </message>
</context>
<context>
    <name>TWScriptable</name>
    <message>
        <source>Script &quot;%1&quot;: %2</source>
        <translation>Eklenti &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <source>Script result</source>
        <translation>Eklenti sonucu</translation>
    </message>
    <message>
        <source>unknown error</source>
        <translation>bilinmeyen hata</translation>
    </message>
    <message>
        <source>Scripts may be used to add new commands to %1, and to extend or modify its behavior.</source>
        <translation>Eklentiler kullanılarak %1&apos;e yeni komutlar eklenebilir, ve davranışı değiştirilebilir veya çeşitlendirilebilir.</translation>
    </message>
    <message>
        <source>For more information on creating and using scripts, see %1&lt;/p&gt;</source>
        <translation>Eklenti oluşturma ve kullanma hakkında daha fazla bilgi için, bkz. %1&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Scripting languages currently available in this copy of %1:</source>
        <translation>Bu %1 kopyasında mevcut eklenti dilleri:</translation>
    </message>
    <message>
        <source>About Scripts</source>
        <translation>Eklentiler Hakkında</translation>
    </message>
    <message>
        <source>Script error</source>
        <translation>Eklenti hatası</translation>
    </message>
    <message>
        <source>(disabled in the preferences)</source>
        <extracomment>This string is appended to a script language name to indicate it is currently disabled</extracomment>
        <translation>(tercihlerden etkisizleştirilmiş)</translation>
    </message>
</context>
<context>
    <name>TWSystemCmd</name>
    <message>
        <source>ERROR: failure code %1</source>
        <translation>HATA: %1 hata kodu</translation>
    </message>
    <message>
        <source>ERROR: exit code %1</source>
        <translation>HATA: %1 çıkış kodu</translation>
    </message>
</context>
<context>
    <name>TagsDock</name>
    <message>
        <source>Tags</source>
        <translation>Etiketler</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Yer imleri</translation>
    </message>
    <message>
        <source>Outline</source>
        <translation>Ana hatlar</translation>
    </message>
    <message>
        <source>No tags</source>
        <translation>Etiket yok</translation>
    </message>
</context>
<context>
    <name>TeXDocument</name>
    <message>
        <source>New document</source>
        <translation>Yeni belge</translation>
    </message>
    <message>
        <source>Open Recent</source>
        <translation>Son Açılanı Aç</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Yok</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Dosya Aç</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Dosyayı Kaydet</translation>
    </message>
    <message>
        <source>The document &quot;%1&quot; has been modified.
Do you want to save your changes?</source>
        <translation>&quot;%1&quot; belgesinde değişiklik yapılmış
Değişikliklerinizi kaydetmek istiyor musunuz?</translation>
    </message>
    <message>
        <source>Do you want to discard all changes to the document &quot;%1&quot;, and revert to the last saved version?</source>
        <translation>&quot;%1&quot; belgesindeki tüm değişikliklerden vazgeçip, kaydedilmiş son versiyona geri dönmek istiyor musunuz?</translation>
    </message>
    <message>
        <source>Revert</source>
        <translation>Geri Dön</translation>
    </message>
    <message>
        <source>Unrecognized encoding</source>
        <translation>Tanınmayan kodlama</translation>
    </message>
    <message>
        <source>The text encoding %1 used in %2 is not supported.

It will be interpreted as %3 instead, which may result in incorrect text.</source>
        <translation>%2&apos;de kullanılan %1 metin kodlaması desteklenmiyor.

Onun yerine, hatalı metne yol açabilecek olan %3 olarak yorumlanacak.</translation>
    </message>
    <message>
        <source>File changed on disk</source>
        <translation>Diskteki dosya değişti</translation>
    </message>
    <message>
        <source>%1 has been modified by another program.

Do you want to discard your current changes, and reload the file from disk?</source>
        <translation>%1 başka bir program tarafından değiştirildi.￼

Şu anki değişikliklerinizden vazgeçip, diskten tekrar yüklemek istiyor musunuz?</translation>
    </message>
    <message>
        <source>%1 has been modified by another program.

Do you want to proceed with saving this file, overwriting the version on disk?</source>
        <translation>%1 başka bir program tarafından değiştirildi.￼

Diskteki versiyonun üzerine yazarak bu dosyayı kaydetmek istiyor musunuz?</translation>
    </message>
    <message>
        <source>Document &quot;%1&quot; was not saved</source>
        <translation>&quot;%1&quot; belgesi kaydedilmedi</translation>
    </message>
    <message>
        <source>Text cannot be converted</source>
        <translation>Metin dönüştürülemedi</translation>
    </message>
    <message>
        <source>This document contains characters that cannot be represented in the encoding %1.

If you proceed, they will be replaced with default codes. Alternatively, you may wish to use a different encoding (such as UTF-8) to avoid loss of data.</source>
        <translation>Bu belgede %1 kodlaması ile gösterilemeyecek karakterler bulunuyor.

Devam ederseniz varsayılan kodlar ile yer değiştirilecek. Alternatif olarak, veri kaybını önlemek için (UTF-8 gibi) başka bir kodlama kullanmak isteyebilirsiniz.</translation>
    </message>
    <message>
        <source>untitled-%1.tex</source>
        <translation>isimsiz-%1.tex</translation>
    </message>
    <message>
        <source>%1[*] - %2</source>
        <translation>%1[*] - %2</translation>
    </message>
    <message>
        <source>Line %1 of %2; col %3</source>
        <translation>Satır %1/%2; sütun %3</translation>
    </message>
    <message>
        <source>Go to Line</source>
        <translation>Satıra Git</translation>
    </message>
    <message>
        <source>Line number:</source>
        <translation>Satır no:</translation>
    </message>
    <message>
        <source>Invalid regular expression</source>
        <translation>Geçersiz düzenli ifade</translation>
    </message>
    <message>
        <source>Not found</source>
        <translation>Bulunamadı</translation>
    </message>
    <message numerus="yes">
        <source>Found %n occurrence(s)</source>
        <translation>
            <numerusform>%n yerde bulundu</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n occurrence(s)</source>
        <translation>
            <numerusform>%n yerde bulundu</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n documents</source>
        <translation>
            <numerusform>%n belge</numerusform>
        </translation>
    </message>
    <message>
        <source>Replaced %1 in %2</source>
        <translation>%1/%2 yer değiştirildi</translation>
    </message>
    <message numerus="yes">
        <source>Replaced %n occurrence(s)</source>
        <translation>
            <numerusform>%n yerde değiştirildi</numerusform>
        </translation>
    </message>
    <message>
        <source>Cannot process unsaved document</source>
        <translation>Kaydedilmemiş belge işlenemiyor</translation>
    </message>
    <message>
        <source>Root document %1 is not readable</source>
        <translation>Ana belge %1 okunabilir değil</translation>
    </message>
    <message>
        <source>%1 is not properly configured</source>
        <translation>%1 uygun şekilde ayarlanmamış</translation>
    </message>
    <message>
        <source>Unable to execute %1</source>
        <translation>%1 çalıştırılamıyor</translation>
    </message>
    <message>
        <source>Set engine to &quot;%1&quot;</source>
        <translation>Araç olarak &quot;%1&quot; ayarla</translation>
    </message>
    <message>
        <source>Engine &quot;%1&quot; not defined</source>
        <translation>&quot;%1&quot; aracı tanımlı değil</translation>
    </message>
    <message>
        <source>No files found</source>
        <translation>Hiç dosya bulunamadı</translation>
    </message>
    <message>
        <source>No auxiliary files associated with this document at the moment.</source>
        <translation>Şu anda bu belge ile ilişkilendirilmiş hiçbir yardımcı dosya yok.</translation>
    </message>
    <message>
        <source>untitled.tex[*]</source>
        <translation>isimsiz.tex[*]</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Dosya</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <source>Spelling</source>
        <translation>Yazım Denetimi</translation>
    </message>
    <message>
        <source>Change Case</source>
        <translation>Büyük küçük harf değiştir</translation>
    </message>
    <message>
        <source>Typeset</source>
        <translation>Diz</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Pencere</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Göster</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Biçim</translation>
    </message>
    <message>
        <source>Auto-indent Mode</source>
        <translation>Otomatik girintileme kipi</translation>
    </message>
    <message>
        <source>Syntax Coloring</source>
        <translation>Sentaks renklendirme</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <source>Typeset Toolbar</source>
        <translation>Dizgi Araç çubuğu</translation>
    </message>
    <message>
        <source>Edit Toolbar</source>
        <translation>Düzenleme Araç Çubuğu</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Yeni</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Aç...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Farklı Kaydet...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <source>Revert to Saved</source>
        <translation>Kaydedilene Geri Dön</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Geri Al</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Tekrar yap</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Z</source>
        <translation>Ctrl+Shift+Z</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Kes</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Yapıştır</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Temizle</translation>
    </message>
    <message>
        <source>Find...</source>
        <translation>Bul...</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Find Again</source>
        <translation>Tekrar Bul</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Replace...</source>
        <translation>Yer Değiştir...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Copy to Find</source>
        <translation>Bul&apos;a Kopyala</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Copy to Replace</source>
        <translation>Yer Değiştir&apos;e Kopyala</translation>
    </message>
    <message>
        <source>Ctrl+Shift+E</source>
        <translation>Ctrl+Shift+E</translation>
    </message>
    <message>
        <source>Go to Line...</source>
        <translation>Satıra Git...</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Find Selection</source>
        <translation>Seçileni Bul</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Tümünü Seç</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>Font...</source>
        <translation>Font...</translation>
    </message>
    <message>
        <source>Indent</source>
        <translation>Girintile</translation>
    </message>
    <message>
        <source>Ctrl+]</source>
        <translation>Ctrl+]</translation>
    </message>
    <message>
        <source>Unindent</source>
        <translation>Girintilemeyi geri al</translation>
    </message>
    <message>
        <source>Ctrl+[</source>
        <translation>Ctrl+[</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Açıklama haline getir</translation>
    </message>
    <message>
        <source>Ctrl+Shift+]</source>
        <translation>Ctrl+Shift+]</translation>
    </message>
    <message>
        <source>Uncomment</source>
        <translation>Açıklama halini kaldır</translation>
    </message>
    <message>
        <source>Ctrl+Shift+[</source>
        <translation>Ctrl+Shift+[</translation>
    </message>
    <message>
        <source>Wrap Lines</source>
        <translation>Sözcük Kaydır</translation>
    </message>
    <message>
        <source>About TeXworks...</source>
        <translation>TeXworks Hakkında...</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Üst üste</translation>
    </message>
    <message>
        <source>Tile</source>
        <translation>Döşe</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>Tercihler...</translation>
    </message>
    <message>
        <source>Go to Preview</source>
        <translation>Önizlemeye Git</translation>
    </message>
    <message>
        <source>Ctrl+&apos;</source>
        <translation>Ctrl+&apos;</translation>
    </message>
    <message>
        <source>Ctrl+\</source>
        <translation>Ctrl+\</translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>Şablondan Yeni...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>Show Selection</source>
        <translation>Seçileni Göster</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>ALL UPPERCASE</source>
        <translation>TÜMÜ BÜYÜK HARF</translation>
    </message>
    <message>
        <source>all lowercase</source>
        <translation>tümü küçük harf</translation>
    </message>
    <message>
        <source>Balance Delimiters</source>
        <translation>Ayraçları Dengele</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>TeXworks ana sayfasına git</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>Posta listesine e-posta gönder</translation>
    </message>
    <message>
        <source>Side by Side</source>
        <translation>Yan yana</translation>
    </message>
    <message>
        <source>Place on Left</source>
        <translation>Sola yerleştir</translation>
    </message>
    <message>
        <source>Place on Right</source>
        <translation>Sağa Yerleştir</translation>
    </message>
    <message>
        <source>Replace Again</source>
        <translation>Tekrar Yer Değiştir</translation>
    </message>
    <message>
        <source>Ctrl+Shift+R</source>
        <translation>Ctrl+Shift+R</translation>
    </message>
    <message>
        <source>Remove Aux Files...</source>
        <translation>Yardımcı Dosyaları Sil...</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>TeXworks&apos;den çık</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Smart Quotes</source>
        <translation>Akıllı Tırnak işaretleri</translation>
    </message>
    <message>
        <source>Toggle Case</source>
        <translation>Büyük küçük harf değiştir</translation>
    </message>
    <message>
        <source>Hard Wrap...</source>
        <translation>Sabit Sözcük Kaydırma...</translation>
    </message>
    <message>
        <source>The program &quot;%1&quot; was not found.</source>
        <translation>&quot;%1&quot; programı bulunamadı.</translation>
    </message>
    <message>
        <source>Searched in directories:</source>
        <translation>Şu dizinlerde arandı:</translation>
    </message>
    <message>
        <source>Line Numbers</source>
        <translation>Satır Numaraları</translation>
    </message>
    <message>
        <source>Process interrupted by user</source>
        <translation>İşlem kullanıcı tarafından kesildi</translation>
    </message>
    <message>
        <source>Typeset</source>
        <comment>menu title</comment>
        <translation>Diz</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <comment>action</comment>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Console output</source>
        <translation>Konsol çıktısı</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Eklentiler</translation>
    </message>
    <message>
        <source>Scripting TeXworks</source>
        <translation>TeXworks Eklentileri</translation>
    </message>
    <message>
        <source>Show Scripts Folder</source>
        <translation>Eklenti Klasörünü Göster</translation>
    </message>
    <message>
        <source>Reload Script List</source>
        <translation>Eklenti Listesini Yenile</translation>
    </message>
    <message>
        <source>Manage Scripts</source>
        <translation>Eklentileri Yönet</translation>
    </message>
    <message>
        <source>Auto-Follow Focus</source>
        <translation>Odak imleçi takip etsin</translation>
    </message>
    <message>
        <source>About Scripts...</source>
        <translation>Eklentiler Hakkında...</translation>
    </message>
    <message>
        <source>Apply to Selection</source>
        <translation>Seçime Uygula</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation>Tümünü Kaydet</translation>
    </message>
    <message>
        <source>Ctrl+Alt+S</source>
        <translation>Ctrl+Alt+S</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <comment>shortcut: Don&apos;t Save</comment>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <comment>shortcut: Revert</comment>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Cannot read file &quot;%1&quot;:
%2</source>
        <translation>&quot;%1&quot; dosyası okunamıyor:￼
%2</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; loaded</source>
        <translation>&quot;%1&quot; dosyası yüklendi</translation>
    </message>
    <message>
        <source>%1 is constantly being modified by another program.

Please use &quot;File &gt; Revert to Saved&quot; manually when the external process has finished.</source>
        <translation>%1 başka bir program tarafından sürekli değiştiriliyor.

Haricî süreç tamamlandığında lütfen &quot;Dosya -&gt; Kaydedilene Geri Dön&quot; kullanın.</translation>
    </message>
    <message>
        <source>Cannot write file &quot;%1&quot;:
%2</source>
        <translation>&quot;%1&quot; dosyası yazılamıyor:￼
%2</translation>
    </message>
    <message>
        <source>Error writing file</source>
        <translation>Dosya yazılırken hata</translation>
    </message>
    <message>
        <source>An error may have occurred while saving the file. You might like to save a copy in a different location.</source>
        <translation>Dosyayı kaydederken bir hata meydana gelmiş olabilir. Farklı bir konuma bir kopya kaydetmek isteyebilirsiniz.</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; saved</source>
        <translation>&quot;%1&quot; dosyası kaydedildi</translation>
    </message>
    <message>
        <source>Abort typesetting</source>
        <translation>Dizgiyi durdur</translation>
    </message>
    <message>
        <source>Settings and Resources...</source>
        <translation>Ayarlar ve Kaynaklar...</translation>
    </message>
    <message>
        <source>Reload using selected encoding</source>
        <extracomment>Item in the encoding popup menu</extracomment>
        <translation>Seçili kodlama ile tekrar yükle</translation>
    </message>
    <message>
        <source>Reloads the current file with the encoding selected from this menu.

The selected encoding replaces the default one and overrides all &quot;%!TEX encoding&quot; lines.</source>
        <extracomment>Tooltip for &quot;Reload using selected encoding&quot;</extracomment>
        <translation>Mevcut dosyayı bu menüden seçilecek kodlama ile tekrar yükler.

Seçili kodlama öntanımlının yerine geçer ve tüm &quot;%!TEX encoding&quot; satırlarını geçersiz kılar.</translation>
    </message>
    <message>
        <source>Unsaved changes</source>
        <translation>Kaydedilmemiş değişiklikler</translation>
    </message>
    <message>
        <source>The file you are trying to reload has unsaved changes.

Do you want to discard your current changes, and reload the file from disk with the encoding %1?</source>
        <translation>Tekrar yüklemeye çalıştığınız dosyada kaydedilmemiş değişiklikler var.

Mevcut değişikliklerinizi gözardı etmek, ve dosyayı diskten %1 kodlaması ile tekrar yüklemek istiyor musunuz?</translation>
    </message>
    <message>
        <source>Clear Recent Files</source>
        <translation>Son kullanılanları temizle</translation>
    </message>
    <message>
        <source>Abort typesetting?</source>
        <translation>Dizgi iptal edilsin mi?</translation>
    </message>
    <message>
        <source>A typesetting process is still running and must be stopped before closing this window.
Do you want to stop it now?</source>
        <translation>Bir dizgi işlemi halen devam ediyor ve bu pencereyi kapatmadan önce durdurulması gerekli.
Şimdi durdurmak istiyor musunuz?</translation>
    </message>
    <message>
        <source>You need a &lt;b&gt;TeX distribution&lt;/b&gt; like &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt; or &lt;a href=&quot;http://miktex.org/&quot;&gt;MiKTeX&lt;/a&gt; installed on your system to typeset your document.</source>
        <translation>Belgenizi dizmek için sisteminize &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt; veya &lt;a href=&quot;http://miktex.org/&quot;&gt;MiKTeX&lt;/a&gt; gibi bir &lt;b&gt;TeX dağıtımı&lt;/b&gt; kurmanız gerekiyor.</translation>
    </message>
    <message>
        <source>You need a &lt;b&gt;TeX distribution&lt;/b&gt; like &lt;a href=&quot;http://www.tug.org/mactex/&quot;&gt;MacTeX&lt;/a&gt; installed on your system to typeset your document.</source>
        <translation>Belgenizi dizmek için sisteminize &lt;a href=&quot;http://www.tug.org/mactex/&quot;&gt;MacTeX&lt;/a&gt; gibi bir &lt;b&gt;TeX dağıtımı&lt;/b&gt; kurmanız gerekiyor.</translation>
    </message>
    <message>
        <source>You need a &lt;b&gt;TeX distribution&lt;/b&gt; like &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt; installed on your system to typeset your document. On most systems such a TeX distribution is available as prebuilt package.</source>
        <translation>Belgenizi dizmek için sisteminize &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt; gibi bir &lt;b&gt;TeX dağıtımı&lt;/b&gt; kurmanız gerekiyor. Çoğu sistem için böyle bir TeX dağıtımı hazır paket şeklinde mevcuttur.</translation>
    </message>
    <message>
        <source>When a TeX distribution is installed you may need to tell TeXworks where to find it in Edit -&gt; Preferences -&gt; Typesetting.</source>
        <translation>Bir TeX dağıtımı kurulduğunda TeXworks&apos;e onu nerede bulabileceğini Düzenle -&gt; Tercihler -&gt; Dizgi ile anlatmanız gerekebilir.</translation>
    </message>
    <message>
        <source>Check the configuration of the %1 tool and the path settings in the Preferences dialog.</source>
        <translation>%1 aracının konfigürasonunu ve yol ayarlarını Tercihler penceresinden kontrol edit.</translation>
    </message>
    <message>
        <source>Hide Console Output</source>
        <translation>Konsol Çıktısını Gizle</translation>
    </message>
    <message>
        <source>Layout Problem</source>
        <translation>Yerleşim Problemi</translation>
    </message>
    <message>
        <source>A problem occured while laying out the loaded document in the editor. This is caused by an issue in the underlying Qt framework and can cause TeXworks to crash under certain circumstances. The symptoms of this problem are hidden or overlapping lines. To work around this, please try one of the following:
 -) Turn syntax highlighting off and on
 -) Turn line numbers off and on
 -) Resize the window

We are sorry for the inconvenience.</source>
        <translation>Yüklenen belgeyi düzenleyiciye yerleştirirken bir sorun ortaya çıktı. Bu Qt çatısından kaynaklanıyor ve bazı durumlarda TeXworks&apos;ün çökmesine neden olabilir. Bu sorun gizli veya üst üste binen satırlar olarak gözlenebilir. Aşağıdakilerden birini deneyerek bunun üstesinden gelebilirsiniz:
 -) Sentaks renklendirmeyi kapatıp açın
 -) Satır numaralarını kapatıp açın
 -) Pencereyi boyutunu değiştirin

Rahatsızlık için üzgünüz.</translation>
    </message>
    <message>
        <source>Show Console Output</source>
        <translation>Konsol Çıktısını Göster</translation>
    </message>
    <message>
        <source>Write UTF-8 byte order mark</source>
        <translation>UTF-8 BOM yaz</translation>
    </message>
</context>
<context>
    <name>TeXHighlighter</name>
    <message>
        <source>default</source>
        <translation>öntanımlı</translation>
    </message>
</context>
<context>
    <name>TemplateDialog</name>
    <message>
        <source>New File using Template</source>
        <translation>Şablon kullanarak Yeni Dosya</translation>
    </message>
    <message>
        <source>Choose template for the new document:</source>
        <translation>Yeni dosya için şablon seçin:</translation>
    </message>
</context>
<context>
    <name>ToolConfig</name>
    <message>
        <source>NewArgument</source>
        <translation>YeniArgüman</translation>
    </message>
    <message>
        <source>Select program file</source>
        <translation>Program dosyası seçin</translation>
    </message>
    <message>
        <source>Invalid program</source>
        <translation>Geçersiz program</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; is not executable!</source>
        <translation>&apos;%1&apos; dosyası çalıştırılabilir değil!</translation>
    </message>
</context>
<context>
    <name>ToolConfigDialog</name>
    <message>
        <source>Tool Configuration</source>
        <translation>Araç Yapılandırması</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>İsim:</translation>
    </message>
    <message>
        <source>Program:</source>
        <translation>Önizleme:</translation>
    </message>
    <message>
        <source>Arguments:</source>
        <translation>Argümanlar:</translation>
    </message>
    <message>
        <source>View PDF after running</source>
        <translation>Çalıştırdıktan sonra PDF&apos;i göster</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Göz at...</translation>
    </message>
</context>
</TS>
